==> react-tooltip-3.1.8.jar: META-INF/resources/webjars/react-tooltip/3.1.8/CHANGELOG.md <==
## Change Log

### 3.1.8 (2016/09/14 13:37 +00:00)
- [#194](https://github.com/wwayne/react-tooltip/pull/194) Add resizeHide option (@wwayne)
- [#193](https://github.com/wwayne/react-tooltip/pull/193) hide specific tooltip (@wwayne)
- [#192](https://github.com/wwayne/react-tooltip/pull/192) Create scroll hide option (@wwayne)

### 3.1.7 (2016/09/07 00:46 +00:00)
- [#187](https://github.com/wwayne/react-tooltip/pull/187) Add disable option (@wwayne)
- [#183](https://github.com/wwayne/react-tooltip/pull/183) Remove react-dom from Bower dependencies (@mikkopiu)

### 3.1.6 (2016/08/19 02:07 +00:00)
- [#181](https://github.com/wwayne/react-tooltip/pull/181) Judge if the component has been mounted mount in getContent #180 (@wwayne)
- [#179](https://github.com/wwayne/react-tooltip/pull/179) Add bower.json (@mikkopiu)

### 3.1.5 (2016/08/04 10:43 +00:00)
- [#176](https://github.com/wwayne/react-tooltip/pull/176) Support ReactTooltip.show() #47 (@wwayne)
- [#174](https://github.com/wwayne/react-tooltip/pull/174) Factor transform in css into position calculation #152 (@wwayne)

### 3.1.4 (2016/08/03 13:52 +00:00)
- [#173](https://github.com/wwayne/react-tooltip/pull/173) Add new attribute afterShow and afterHide (@wwayne)
- [#172](https://github.com/wwayne/react-tooltip/pull/172) Add support for aria- and role props #159 (@wwayne)

### 3.1.3 (2016/08/01 23:53 +00:00)
- [#164](https://github.com/wwayne/react-tooltip/pull/164) Fix for delayShwo #163 (@wwayne)

### 3.1.2 (2016/07/30 01:38 +00:00)
- [#162](https://github.com/wwayne/react-tooltip/pull/162) Fix for #158, getposition error (@wwayne)

### 3.1.1 (2016/07/27 13:03 +00:00)
- [#151](https://github.com/wwayne/react-tooltip/pull/151) Update postion calculation so that it can calculate continous tootlip (@wwayne)

### 3.1.0 (2016/07/27 08:49 +00:00)
- [#149](https://github.com/wwayne/react-tooltip/pull/149) Update algorithm for get positon to fix the shake problem #146 (@wwayne)
- [#145](https://github.com/wwayne/react-tooltip/pull/145) fix typo (@meandavejustice)

### 3.0.13 (2016/07/14 09:53 +00:00)
- [#136](https://github.com/wwayne/react-tooltip/pull/136) Check if current element is under transform (@CremAlex)
- [#135](https://github.com/wwayne/react-tooltip/pull/135) Transform 3d (@wwayne)

### 3.0.10 (2016/07/12 00:28 +00:00)
- [#132](https://github.com/wwayne/react-tooltip/pull/132) Make getContent to support dynamical generate content while hover (@wwayne)
- [#131](https://github.com/wwayne/react-tooltip/pull/131) Add possibility to recalculate content on show tooltip (@pokidovea)
- [#128](https://github.com/wwayne/react-tooltip/pull/128) Correct Typos in README.md (@gottsohn)

### 3.0.7 (2016/06/24 13:58 +00:00)
- [#124](https://github.com/wwayne/react-tooltip/pull/124) Consider both vertical and horizontal into place re-calculation (@wwayne)

### 3.0.6 (2016/06/23 01:08 +00:00)
- [#122](https://github.com/wwayne/react-tooltip/pull/122) Fixed "Wrong query selector for data-tip #121" (@neciu)

### 3.0.5 (2016/06/21 00:32 +00:00)
- [#120](https://github.com/wwayne/react-tooltip/pull/120) Fix custom event with specific id (@wwayne)

### 3.0.4 (2016/06/17 10:28 +00:00)
- [#117](https://github.com/wwayne/react-tooltip/pull/117) Improve deploy process (@wwayne)

### 3.0.0 (2016/06/16 12:39 +00:00)
- [#115](https://github.com/wwayne/react-tooltip/pull/115) Improve structure (@wwayne)
- [#106](https://github.com/wwayne/react-tooltip/pull/106) Workaround for fixed elements inside transformed elements (@nd0ut)

### 2.0.3 (2016/06/01 13:45 +00:00)
- [#112](https://github.com/wwayne/react-tooltip/pull/112) Add custom event to hide tooltip (@wwayne)
- [#103](https://github.com/wwayne/react-tooltip/pull/103) Allow user to specify separate off event for the tooltip (@ondy1985)

### 2.0.2 (2016/05/19 10:01 +00:00)
- [#104](https://github.com/wwayne/react-tooltip/pull/104) Ensure data-html is converted to bool type (@antoniodgonzalez)

### 2.0.1 (2016/05/14 00:32 +00:00)
- [#102](https://github.com/wwayne/react-tooltip/pull/102) Clear hide timeout on component unmount (@oluckyman)
- [#100](https://github.com/wwayne/react-tooltip/pull/100) correct spelling error (@SashaBayan)
- [#99](https://github.com/wwayne/react-tooltip/pull/99) Simplify setting Sstate in the showTooltip (@Kiwka)

### 2.0.0 (2016/04/29 01:07 +00:00)
- [#96](https://github.com/wwayne/react-tooltip/pull/96) New attribute isCapture, deprecate eventPropagationMode (@wwayne)

### 1.2.1 (2016/04/23 00:16 +00:00)
- [#95](https://github.com/wwayne/react-tooltip/pull/95) Added ability to change event propagation mode from default "bubble" to "capture" (@aweber1)
- [#93](https://github.com/wwayne/react-tooltip/pull/93) Upgrade classnames to `^2.2.0` (@petrbrzek)
- [#92](https://github.com/wwayne/react-tooltip/pull/92) Update peer dependencies to support react / react-dom >= 15.0.0 (@cchamberlain)

### v1.1.3 (2016/03/10 12:57 +00:00)
- [#84](https://github.com/wwayne/react-tooltip/pull/84) Add logic to handle outside cases for solid tooltips #83 (@andrejunges)
- [#81](https://github.com/wwayne/react-tooltip/pull/81) Fix typo (@robzolkos)

### v1.1.2 (2016/02/15 12:31 +00:00)
- [#79](https://github.com/wwayne/react-tooltip/pull/79) Require the non-minified dist build in index (@idan)
- [#73](https://github.com/wwayne/react-tooltip/pull/73) Clear timeout when unmounting. (@joelburget)
- [#72](https://github.com/wwayne/react-tooltip/pull/72) clearing delayShowLoop-Timeout when component will unmount (@Monterra)

### v1.0.0 (2016/01/10 02:16 +00:00)
- [#68](https://github.com/wwayne/react-tooltip/pull/68) better fix for Maximum call stack size exceeded (@enjalot)
- [#62](https://github.com/wwayne/react-tooltip/pull/62) Fixes IE's lacking event constructor (@mikkelvagn)
- [#54](https://github.com/wwayne/react-tooltip/pull/54) New Feature: watchWindow (@Sly777)
- [#55](https://github.com/wwayne/react-tooltip/pull/55) Add support for borders (@ahstro)
- [#1](https://github.com/wwayne/react-tooltip/pull/1) New Feature: watchWindow (@Sly777)

### v0.9.0 (2015/11/26 14:09 +00:00)
- [#53](https://github.com/wwayne/react-tooltip/pull/53) New Feature, Fixes (@Sly777)

### v0.5.0 (2015/09/13 00:55 +00:00)
- [#36](https://github.com/wwayne/react-tooltip/pull/36) also babelify and move style.js to dist (@conorhastings)
- [#34](https://github.com/wwayne/react-tooltip/pull/34) avoid getBoundingClientRect() to be called twice (@ruffle1986)

### v0.3.7 (2015/08/18 13:44 +00:00)
- [#26](https://github.com/wwayne/react-tooltip/pull/26) Add editorconfig and eslinter to project (@johnamiahford)

### v0.3.5 (2015/08/02 10:58 +00:00)
- [#22](https://github.com/wwayne/react-tooltip/pull/22) Convert ReactTooltip to es6 class (@johnamiahford)
- [#19](https://github.com/wwayne/react-tooltip/pull/19) remove querySelector and use findDOMNode instead (@bezreyhan)

### v0.3.0 (2015/06/17 08:46 +00:00)
- [#15](https://github.com/wwayne/react-tooltip/pull/15) Adding support for server-side rendering (@bluejamesbond)
- [#8](https://github.com/wwayne/react-tooltip/pull/8) Change curly brackets to quotes (single) (@af7)
- [#6](https://github.com/wwayne/react-tooltip/pull/6) Fix bug with mouse hover triggerring on tooltip children (@tom-s)
- [#5](https://github.com/wwayne/react-tooltip/pull/5) fixed classnames require call (@mciparelli)

==> react-tooltip-3.4.0.jar: META-INF/resources/webjars/react-tooltip/3.4.0/CHANGELOG.md <==
## Change Log

### 3.4.0 (2017/10/16 13:36 +00:00)
- [#321](https://github.com/wwayne/react-tooltip/pull/321) React 16 support (@mikecousins)

### 3.3.1 (2017/10/05 05:08 +00:00)
- [#292](https://github.com/wwayne/react-tooltip/pull/292) Fix typo (@piperchester)

### 3.3.0 (2017/04/14 03:34 +00:00)
- [#287](https://github.com/wwayne/react-tooltip/pull/287) Use prop-types package instead of React.PropTypes (@ssilve1989)

### 3.2.10 (2017/03/28 20:41 +00:00)
- [#278](https://github.com/wwayne/react-tooltip/pull/278) Make MutationObserver-based removal tracking (@huumanoid)
- [#272](https://github.com/wwayne/react-tooltip/pull/272) Fix wrapper tag (@huumanoid)
- [#259](https://github.com/wwayne/react-tooltip/pull/259) Track removal of DOM elements (@antoniogiordano)
- [#270](https://github.com/wwayne/react-tooltip/pull/270) Fix typos and improve for clarity (@theholla)

### 3.2.9 (2017/03/20 15:41 +00:00)
- [#236](https://github.com/wwayne/react-tooltip/pull/236) escape backslash in getTargetArray method (@rnons)

### 3.2.7 (2017/02/17 07:24 +00:00)
- [#262](https://github.com/wwayne/react-tooltip/pull/262) Fix nodelist converte in safari (@wwayne)
- [#260](https://github.com/wwayne/react-tooltip/pull/260) Fix NodeList to Array convertion (@huumanoid)

### 3.2.6 (2017/02/08 12:34 +00:00)
- [#255](https://github.com/wwayne/react-tooltip/pull/255) (fix) Remove console logs (@flexpert)
- [#254](https://github.com/wwayne/react-tooltip/pull/254) Add support for className prop (@jonbeller)

### 3.2.4 (2017/02/07 03:57 +00:00)
- [#251](https://github.com/wwayne/react-tooltip/pull/251) Dropfen dynamic wrapper (@dropfen)

### 3.2.3 (2017/01/30 03:00 +00:00)
- [#247](https://github.com/wwayne/react-tooltip/pull/247) Fix delayHide issue #246 (@huumanoid)
- [#238](https://github.com/wwayne/react-tooltip/pull/238) Update README.md (@nikbelikov)
- [#233](https://github.com/wwayne/react-tooltip/pull/233) Added more syntax highlighting (@oyeanuj)
- [#229](https://github.com/wwayne/react-tooltip/pull/229) Replaced Object.keys(...) by Object.getOwnPropertyNames(...) (@gauthierj)

### 3.2.2 (2016/11/23 08:23 +00:00)
- [#220](https://github.com/wwayne/react-tooltip/pull/220) Use parameter 'useCapture' for remove listener if it is registered as… (@achernetsky)
- [#223](https://github.com/wwayne/react-tooltip/pull/223) Fix/security csp style src (@briantrice)
- [#216](https://github.com/wwayne/react-tooltip/pull/216) Fix fire of global show event for IE (@SubVersive)

### 3.2.1 (2016/09/30 09:51 +00:00)
- [#202](https://github.com/wwayne/react-tooltip/pull/202) Hide tooltip when getContent return null or undefined, same for empty… (@wwayne)
- [#201](https://github.com/wwayne/react-tooltip/pull/201) Hide tooltip if the tip is empty or disabled (@wwayne)

### 3.2.0 (2016/09/30 01:10 +00:00)
- [#200](https://github.com/wwayne/react-tooltip/pull/200) Remove countTransform because the way of transform calculation is cha… (@wwayne)
- [#195](https://github.com/wwayne/react-tooltip/pull/195) Use node parent when calculating offset (@iamdoron)

### 3.1.8 (2016/09/14 13:37 +00:00)
- [#194](https://github.com/wwayne/react-tooltip/pull/194) Add resizeHide option (@wwayne)
- [#193](https://github.com/wwayne/react-tooltip/pull/193) hide specific tooltip (@wwayne)
- [#192](https://github.com/wwayne/react-tooltip/pull/192) Create scroll hide option (@wwayne)

### 3.1.7 (2016/09/07 00:46 +00:00)
- [#187](https://github.com/wwayne/react-tooltip/pull/187) Add disable option (@wwayne)
- [#183](https://github.com/wwayne/react-tooltip/pull/183) Remove react-dom from Bower dependencies (@mikkopiu)

### 3.1.6 (2016/08/19 02:07 +00:00)
- [#181](https://github.com/wwayne/react-tooltip/pull/181) Judge if the component has been mounted mount in getContent #180 (@wwayne)
- [#179](https://github.com/wwayne/react-tooltip/pull/179) Add bower.json (@mikkopiu)

### 3.1.5 (2016/08/04 10:43 +00:00)
- [#176](https://github.com/wwayne/react-tooltip/pull/176) Support ReactTooltip.show() #47 (@wwayne)
- [#174](https://github.com/wwayne/react-tooltip/pull/174) Factor transform in css into position calculation #152 (@wwayne)

### 3.1.4 (2016/08/03 13:52 +00:00)
- [#173](https://github.com/wwayne/react-tooltip/pull/173) Add new attribute afterShow and afterHide (@wwayne)
- [#172](https://github.com/wwayne/react-tooltip/pull/172) Add support for aria- and role props #159 (@wwayne)

### 3.1.3 (2016/08/01 23:53 +00:00)
- [#164](https://github.com/wwayne/react-tooltip/pull/164) Fix for delayShwo #163 (@wwayne)

### 3.1.2 (2016/07/30 01:38 +00:00)
- [#162](https://github.com/wwayne/react-tooltip/pull/162) Fix for #158, getposition error (@wwayne)

### 3.1.1 (2016/07/27 13:03 +00:00)
- [#151](https://github.com/wwayne/react-tooltip/pull/151) Update postion calculation so that it can calculate continous tootlip (@wwayne)

### 3.1.0 (2016/07/27 08:49 +00:00)
- [#149](https://github.com/wwayne/react-tooltip/pull/149) Update algorithm for get positon to fix the shake problem #146 (@wwayne)
- [#145](https://github.com/wwayne/react-tooltip/pull/145) fix typo (@meandavejustice)

### 3.0.13 (2016/07/14 09:53 +00:00)
- [#136](https://github.com/wwayne/react-tooltip/pull/136) Check if current element is under transform (@CremaFR)
- [#135](https://github.com/wwayne/react-tooltip/pull/135) Transform 3d (@wwayne)

### 3.0.10 (2016/07/12 00:28 +00:00)
- [#132](https://github.com/wwayne/react-tooltip/pull/132) Make getContent to support dynamical generate content while hover (@wwayne)
- [#131](https://github.com/wwayne/react-tooltip/pull/131) Add possibility to recalculate content on show tooltip (@pokidovea)
- [#128](https://github.com/wwayne/react-tooltip/pull/128) Correct Typos in README.md (@gottsohn)

### 3.0.7 (2016/06/24 13:58 +00:00)
- [#124](https://github.com/wwayne/react-tooltip/pull/124) Consider both vertical and horizontal into place re-calculation (@wwayne)

### 3.0.6 (2016/06/23 01:08 +00:00)
- [#122](https://github.com/wwayne/react-tooltip/pull/122) Fixed "Wrong query selector for data-tip #121" (@neciu)

### 3.0.5 (2016/06/21 00:32 +00:00)
- [#120](https://github.com/wwayne/react-tooltip/pull/120) Fix custom event with specific id (@wwayne)

### 3.0.4 (2016/06/17 10:28 +00:00)
- [#117](https://github.com/wwayne/react-tooltip/pull/117) Improve deploy process (@wwayne)

### 3.0.0 (2016/06/16 12:39 +00:00)
- [#115](https://github.com/wwayne/react-tooltip/pull/115) Improve structure (@wwayne)
- [#106](https://github.com/wwayne/react-tooltip/pull/106) Workaround for fixed elements inside transformed elements (@nd0ut)

### 2.0.3 (2016/06/01 13:45 +00:00)
- [#112](https://github.com/wwayne/react-tooltip/pull/112) Add custom event to hide tooltip (@wwayne)
- [#103](https://github.com/wwayne/react-tooltip/pull/103) Allow user to specify separate off event for the tooltip (@ondy1985)

### 2.0.2 (2016/05/19 10:01 +00:00)
- [#104](https://github.com/wwayne/react-tooltip/pull/104) Ensure data-html is converted to bool type (@antoniodgonzalez)

### 2.0.1 (2016/05/14 00:32 +00:00)
- [#102](https://github.com/wwayne/react-tooltip/pull/102) Clear hide timeout on component unmount (@oluckyman)
- [#100](https://github.com/wwayne/react-tooltip/pull/100) correct spelling error (@SashaBayan)
- [#99](https://github.com/wwayne/react-tooltip/pull/99) Simplify setting Sstate in the showTooltip (@Kiwka)

### 2.0.0 (2016/04/29 01:07 +00:00)
- [#96](https://github.com/wwayne/react-tooltip/pull/96) New attribute isCapture, deprecate eventPropagationMode (@wwayne)

### 1.2.1 (2016/04/23 00:16 +00:00)
- [#95](https://github.com/wwayne/react-tooltip/pull/95) Added ability to change event propagation mode from default "bubble" to "capture" (@aweber1)
- [#93](https://github.com/wwayne/react-tooltip/pull/93) Upgrade classnames to `^2.2.0` (@petrbrzek)
- [#92](https://github.com/wwayne/react-tooltip/pull/92) Update peer dependencies to support react / react-dom >= 15.0.0 (@cchamberlain)

### v1.1.3 (2016/03/10 12:57 +00:00)
- [#84](https://github.com/wwayne/react-tooltip/pull/84) Add logic to handle outside cases for solid tooltips #83 (@andrejunges)
- [#81](https://github.com/wwayne/react-tooltip/pull/81) Fix typo (@robzolkos)

### v1.1.2 (2016/02/15 12:31 +00:00)
- [#79](https://github.com/wwayne/react-tooltip/pull/79) Require the non-minified dist build in index (@idan)
- [#73](https://github.com/wwayne/react-tooltip/pull/73) Clear timeout when unmounting. (@joelburget)
- [#72](https://github.com/wwayne/react-tooltip/pull/72) clearing delayShowLoop-Timeout when component will unmount (@dsumer)

### v1.0.0 (2016/01/10 02:16 +00:00)
- [#68](https://github.com/wwayne/react-tooltip/pull/68) better fix for Maximum call stack size exceeded (@enjalot)
- [#62](https://github.com/wwayne/react-tooltip/pull/62) Fixes IE's lacking event constructor (@mikkelvagn)
- [#54](https://github.com/wwayne/react-tooltip/pull/54) New Feature: watchWindow (@Sly777)
- [#55](https://github.com/wwayne/react-tooltip/pull/55) Add support for borders (@ahstro)
- [#1](https://github.com/wwayne/react-tooltip/pull/1) New Feature: watchWindow (@Sly777)

### v0.9.0 (2015/11/26 14:09 +00:00)
- [#53](https://github.com/wwayne/react-tooltip/pull/53) New Feature, Fixes (@Sly777)

### v0.5.0 (2015/09/13 00:55 +00:00)
- [#36](https://github.com/wwayne/react-tooltip/pull/36) also babelify and move style.js to dist (@conorhastings)
- [#34](https://github.com/wwayne/react-tooltip/pull/34) avoid getBoundingClientRect() to be called twice (@ruffle1986)

### v0.3.7 (2015/08/18 13:44 +00:00)
- [#26](https://github.com/wwayne/react-tooltip/pull/26) Add editorconfig and eslinter to project (@johnamiahford)

### v0.3.5 (2015/08/02 10:58 +00:00)
- [#22](https://github.com/wwayne/react-tooltip/pull/22) Convert ReactTooltip to es6 class (@johnamiahford)
- [#19](https://github.com/wwayne/react-tooltip/pull/19) remove querySelector and use findDOMNode instead (@bezreyhan)

### v0.3.0 (2015/06/17 08:46 +00:00)
- [#15](https://github.com/wwayne/react-tooltip/pull/15) Adding support for server-side rendering (@bluejamesbond)
- [#8](https://github.com/wwayne/react-tooltip/pull/8) Change curly brackets to quotes (single) (@af7)
- [#6](https://github.com/wwayne/react-tooltip/pull/6) Fix bug with mouse hover triggerring on tooltip children (@tom-s)
- [#5](https://github.com/wwayne/react-tooltip/pull/5) fixed classnames require call (@mciparelli)
